======================================
NIXIO Python Package for NIX Datafiles
======================================

The NIXPy module is a reimplementation of the `NIX C++ library <https://nixio.readthedocs.io>`_.


Getting started
===============

The following sections should help you getting started with NIXPy.

.. toctree::
   :maxdepth: 2

   install
   overview
   tutorial

High Level API Reference
========================

User API documentation for Data and Metadata

.. toctree::
   :maxdepth: 2

   user_api


Advanced
========

Internal NIXIO API Developer Documentation
------------------------------------------

The API documentation of internal modules, for NIXPy developers.

.. toctree::
   :maxdepth: 2

   api/nixio
